@@ -54,8 +54,8 @@ var levelDataset
 function start(items_, dataset_) {
     items = items_
     dataset = dataset_.get()
-    items.currentLevel = 0
     numberOfLevel = dataset.length
+    items.currentLevel = Core.getInitialLevel(numberOfLevel)
 }
 
 function stop() {
@@ -70,26 +70,29 @@ function resetBulbs() {
 function initializeValues() {
     items.currentSelectedBulb = -1
     items.numberSoFar = 0
-    items.numberToConvert = levelDataset[items.score.currentSubLevel - 1]
+    items.numberToConvert = levelDataset[items.score.currentSubLevel]
 }
 
 function equalityCheck() {
+    items.buttonsBlocked = true
     if(items.numberSoFar == items.numberToConvert) {
-        if(items.score.currentSubLevel < items.score.numberOfSubLevels) {
-            items.score.currentSubLevel++;
-            items.score.playWinAnimation()
-            resetBulbs()
-            initializeValues()
-        }
-        else {
-            items.bonus.good("lion")
-            resetBulbs()
-        }
+        items.score.currentSubLevel++
+        items.score.playWinAnimation()
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav")
+
+    } else {
+        items.errorRectangle.startAnimation()
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav")
     }
-    else {
-        items.bonus.bad("lion")
+}
+
+function nextSubLevel() {
+    if (items.score.currentSubLevel >= items.score.numberOfSubLevels) {
+        items.bonus.good("lion")
+    } else {
         resetBulbs()
-        items.numberSoFar = 0
+        initializeValues()
+        items.buttonsBlocked = false
     }
 }
 
@@ -106,33 +109,24 @@ function changeState(index) {
 }
 
 function initLevel() {
-    items.bar.level = items.currentLevel + 1
+    items.errorRectangle.resetState()
     items.score.numberOfSubLevels = dataset[items.currentLevel].numbersToBeConverted.length
-    items.score.currentSubLevel = 1
+    items.score.currentSubLevel = 0
     items.numberOfBulbs = dataset[items.currentLevel].bulbCount
     levelDataset = Core.shuffle(dataset[items.currentLevel].numbersToBeConverted)
     initializeValues()
     resetBulbs()
+    items.buttonsBlocked = false
 }
 
 function nextLevel() {
-    if(numberOfLevel <= items.currentLevel + 1) {
-        items.currentLevel = 0
-    }
-    else {
-        ++ items.currentLevel
-    }
-    items.score.currentSubLevel = 1
+    items.score.stopWinAnimation()
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function previousLevel() {
-    if(items.currentLevel-1 < 0) {
-        items.currentLevel = numberOfLevel - 1
-    }
-    else {
-        --items.currentLevel
-    }
-    items.score.currentSubLevel = 1
+    items.score.stopWinAnimation()
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
