@@ -14,9 +14,7 @@
 .import GCompris 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel = 0
 var numberOfLevel
-var currentSubLevel = 1
 var currentDataSet
 var currentLevelConfig
 var dataset
@@ -30,7 +28,7 @@ function start(items_, dataset_) {
     items = items_
     dataset = dataset_.get()
     numberOfLevel = dataset.length
-    currentLevel = 0
+    items.currentLevel = Core.getInitialLevel(numberOfLevel)
 
     if(Qt.locale(GCompris.ApplicationSettings.locale).firstDayOfWeek == Qml.Locale.Monday) {
         items.daysOfTheWeekModel.move(0, items.daysOfTheWeekModel.count - 1, 1)
@@ -42,24 +40,30 @@ function stop() {
 }
 
 function initLevel() {
-    currentSubLevel = 1;
-    items.bar.level = currentLevel + 1
-    currentLevelConfig = dataset[currentLevel][0][0]
-    setCalendarConfigurations()
+    items.errorRectangle.resetState();
+    items.score.currentSubLevel = 0;
+    currentLevelConfig = dataset[items.currentLevel][0][0];
+    setCalendarConfigurations();
     initQuestion();
 }
 
-function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0
+function nextSubLevel() {
+    if(items.score.currentSubLevel >= currentDataSet.length) {
+        items.bonus.good("lion");
+    } else {
+        initQuestion();
     }
+}
+
+function nextLevel() {
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1
-    }
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
@@ -75,35 +79,32 @@ function setCalendarConfigurations() {
     items.calendar.currentDate = new Date(currentLevelConfig["visibleYear"], currentLevelConfig["visibleMonth"], items.calendar.selectedDay)
     items.answerChoices.visible = (mode === "findDayOfWeek") ? true : false
     items.okButton.visible = !items.answerChoices.visible
-    currentDataSet = dataset[currentLevel][1]
+    currentDataSet = dataset[items.currentLevel][1]
     currentDataSet = Core.shuffle(currentDataSet)
     items.score.numberOfSubLevels = currentDataSet.length
-    items.score.currentSubLevel = currentSubLevel
 }
 
 function initQuestion() {
-    if(currentDataSet.length < currentSubLevel) {
-        items.bonus.good("lion")
-    }
-    else {
-        items.score.currentSubLevel = currentSubLevel
-        items.questionItem.text = currentDataSet[currentSubLevel-1]["question"]
-        correctAnswer = currentDataSet[currentSubLevel-1]["answer"]
-    }
+    items.questionItem.text = currentDataSet[items.score.currentSubLevel]["question"]
+    correctAnswer = currentDataSet[items.score.currentSubLevel]["answer"]
+    items.buttonsBlocked = false
 }
 
 function updateScore(isCorrectAnswer) {
     if(isCorrectAnswer) {
-        items.questionDelay.start()
         items.okButtonParticles.burst(20)
-        items.score.playWinAnimation()
-        currentSubLevel++;
+        items.score.currentSubLevel++;
+        items.score.playWinAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+    }
+    else {
+        items.errorRectangle.startAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
     }
-    else
-        items.bonus.bad("lion", items.bonus.checkAnswer)
 }
 
 function checkAnswer() {
+    items.buttonsBlocked = true
     var isCorrectAnswer = false
     // For levels having questions based on day of week only.
     if(mode === "findDayOfWeek") {
@@ -113,7 +114,7 @@ function checkAnswer() {
     }
     // For levels having question based on month only.
     else if(mode === "findMonthOnly") {
-        if(correctAnswer["month"].indexOf(monthSelected) >= 0) {
+        if(correctAnswer["month"].indexOf(items.calendar.currentDate.getMonth()) != -1) {
             isCorrectAnswer = true
         }
     }
