@@ -17,8 +17,6 @@ var url2 = "qrc:/gcompris/src/activities/algorithm/resource/";
 var items;
 var maxSubLevel;
 var dataset;
-var currentLevel;
-var currentSubLevel;
 var numberOfLevel;
 var numberOfItemType;
 var numberOfItemMax;
@@ -49,7 +47,9 @@ var globalZ = 0;
 function start(items_) {
     items = items_;
     answersMode = items.mode;
-    currentLevel = 0;
+    dataset = items.levels;
+    numberOfLevel = dataset.length;
+    items.currentLevel = Core.getInitialLevel(numberOfLevel);
     initLevel();
 }
 
@@ -59,31 +59,26 @@ function stop() {
 
 function initLevel() {
     if(items.levels) {
-        items.instructionText = items.levels[currentLevel].objective;
+        items.instructionText = items.levels[items.currentLevel].objective;
         items.instruction.opacity = 0.8;
     }
-    items.bar.level = currentLevel + 1;
-    dataset = items.levels;
-    numberOfLevel = dataset.length;
-    currentSubLevel = 0;
-    numberOfItemType = dataset[currentLevel].numberOfItemType;
-    numberOfItemMax = dataset[currentLevel].numberOfItemMax;
-    maxSubLevel = dataset[currentLevel].sublevels;
+    items.score.currentSubLevel = 0;
+    numberOfItemType = dataset[items.currentLevel].numberOfItemType;
+    numberOfItemMax = dataset[items.currentLevel].numberOfItemMax;
+    maxSubLevel = dataset[items.currentLevel].sublevels;
     items.score.numberOfSubLevels = maxSubLevel;
     initSubLevel();
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel ) {
-        currentLevel = 0;
-    }
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1;
-    }
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
@@ -107,7 +102,10 @@ function checkAnswersAuto() {
             return;
         }
     }
-    nextSubLevel();
+    items.buttonsBlocked = true;
+    items.score.currentSubLevel += 1;
+    items.score.playWinAnimation();
+    items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
 }
 
 function checkAnswers() {
@@ -125,11 +123,14 @@ function checkAnswers() {
     }
 
     if(isAnswerGood) {
-        playAudio();
-        nextSubLevel();
+        items.buttonsBlocked = true;
+        items.score.currentSubLevel += 1;
+        items.score.playWinAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+    } else {
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
+        items.errorRectangle.startAnimation();
     }
-    else
-        items.bonus.bad("smiley");
 }
 
 function resetAnswerAreaColor() {
@@ -149,9 +150,9 @@ function registerAnswerItem(item) {
 }
 
 function initSubLevel() {
+    items.errorRectangle.resetState()
     cleanUp();
     itemIcons = Core.shuffle(itemIcons);
-    items.score.currentSubLevel = currentSubLevel + 1;
     items.okButton.enabled = false;
     var enumItems = new Array();
     var types = new Array();
@@ -166,17 +167,17 @@ function initSubLevel() {
     items.answerColumn.model = types;
     items.itemListModel = enumItems;
     lockKeyboard = false;
+    items.buttonsBlocked = false;
 }
 
 function nextSubLevel() {
     lockKeyboard = true;
-    if( ++currentSubLevel >= maxSubLevel) {
+    if( items.score.currentSubLevel >= maxSubLevel) {
         items.okButton.enabled = false;
         items.bonus.good("smiley");
-        currentSubLevel = 0;
     }
     else
-        items.score.playWinAnimation();
+        initSubLevel();
 }
 
 function enableOkButton() {
