@@ -12,7 +12,6 @@
 .import GCompris 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel = 0;
 var numberOfLevel;
 var items;
 var operationMode;
@@ -26,8 +25,7 @@ function start(items_, operationMode_) {
     if(!operationMode && items.voicesEnabled)
         Core.checkForVoices(items_.activityPage);
     numberOfLevel = items.levels.length;
-    currentLevel = 0;
-    initLevel();
+    items.currentLevel = Core.getInitialLevel(numberOfLevel);
 }
 
 function stop() {
@@ -36,17 +34,17 @@ function stop() {
 }
 
 function initLevel() {
+    items.errorRectangle.resetState();
     items.circlesModel = 0
     items.question = 0
     items.questionText = ""
     items.answer = 0
-    items.bar.level = currentLevel + 1;
-    questionsArray = items.levels[currentLevel].questionsArray.slice(0);
+    questionsArray = items.levels[items.currentLevel].questionsArray.slice(0);
     if(operationMode) {
-        answersArray = items.levels[currentLevel].answersArray.slice(0);
+        answersArray = items.levels[items.currentLevel].answersArray.slice(0);
     }
-    items.circlesModel = items.levels[currentLevel].circlesModel;
-    items.currentSubLevel = 0;
+    items.circlesModel = items.levels[items.currentLevel].circlesModel;
+    items.score.currentSubLevel = 0;
     items.nbSubLevel = questionsArray.length;
     if(items.mode === 2)
         url = "qrc:/gcompris/src/activities/learn_digits/resource/dots-";
@@ -61,30 +59,36 @@ function initLevel() {
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0;
-    }
-    items.currentSubLevel = 0;
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
+    items.score.currentSubLevel = 0;
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1;
-    }
-    items.currentSubLevel = 0;
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
+    items.score.currentSubLevel = 0;
     initLevel();
 }
 
 function removeLastQuestion() {
-     for(var i = 0; i < questionsArray.length; i++) {
-         if(questionsArray[i] === items.question)
-            questionsArray.splice(i, 1);
-         else if(questionsArray[i] === items.questionText) {
-            questionsArray.splice(i, 1);
-            answersArray.splice(i, 1);
-         }
-     }
+    if(operationMode) {
+        for(var i = 0; i < questionsArray.length; i++) {
+            if(questionsArray[i] === items.questionText) {
+                questionsArray.splice(i, 1);
+                answersArray.splice(i, 1);
+                return;
+            }
+        }
+    } else {
+        for(var i = 0; i < questionsArray.length; i++) {
+            if(questionsArray[i] === items.question) {
+                questionsArray.splice(i, 1);
+                return;
+            }
+        }
+    }
 }
 
 function initQuestion() {
@@ -103,6 +107,7 @@ function initQuestion() {
     if(items.mode != 1) {
         items.imageSource = url + items.questionText + ".svg"
     }
+    items.inputLocked = false;
 }
 
 function resetCircles() {
@@ -115,15 +120,21 @@ function resetCircles() {
 function checkAnswer() {
     items.inputLocked = true
     if(items.answer === items.question) {
-        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/win.wav");
-        ++items.currentSubLevel;
+        ++items.score.currentSubLevel;
         items.score.playWinAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
         removeLastQuestion();
     } else {
-        items.bonus.bad('flower');
+        items.errorRectangle.startAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
     }
-    if(items.currentSubLevel === items.nbSubLevel) {
+}
+
+function nextSubLevel() {
+    if(items.score.currentSubLevel >= items.nbSubLevel) {
         items.bonus.good('flower');
+    } else {
+        initQuestion();
     }
 }
 
