@@ -58,14 +58,11 @@ var levels = [
 ]
 
 
-var currentImageId;
-var currentLevel;
 var items
 
 function start(items_) {
     items = items_
-    currentLevel = 0
-    items.score.currentSubLevel = 0
+    items.currentLevel = Core.getInitialLevel(levels.length)
     initLevel()
 }
 
@@ -74,10 +71,9 @@ function stop() {
 }
 
 function initLevel() {
-    items.bar.level = currentLevel + 1
-    currentImageId = 0
+    items.score.currentSubLevel = 0
     currentHands = new Array()
-    var level = levels[currentLevel]
+    var level = levels[items.currentLevel]
     var counter = 0
     for (var i = 0 ; i < level.images.length ; i++) {
         for (var r = 0 ; r < level.rotations.length ; r++) {
@@ -94,18 +90,14 @@ function initLevel() {
 }
 
 function nextLevel() {
-    if(levels.length <= ++currentLevel ) {
-        currentLevel = 0
-    }
-    items.score.currentSubLevel = 0
+    items.score.stopWinAnimation()
+    items.currentLevel = Core.getNextLevel(items.currentLevel, levels.length);
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = levels.length - 1
-    }
-    items.score.currentSubLevel = 0
+    items.score.stopWinAnimation()
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, levels.length);
     initLevel();
 }
 
@@ -113,21 +105,20 @@ function displayHand() {
     items.leftButton.isCorrectAnswer = isLeft()
     items.rightButton.isCorrectAnswer = isRight()
     items.imageAnimOff.start()
+    items.buttonsBlocked = false
 }
 
 function getCurrentHandImage() {
     return "qrc:/gcompris/src/activities/leftright/resource/" +
-            currentHands[currentImageId].image
+            currentHands[items.score.currentSubLevel].image
 }
 
 function getCurrentHandRotation() {
-    return currentHands[currentImageId].rotation
+    return currentHands[items.score.currentSubLevel].rotation
 }
 
 function displayNextHand() {
-    items.score.currentSubLevel ++
-    items.score.playWinAnimation();
-    if(currentHands.length <= ++currentImageId ) {
+    if(items.score.currentSubLevel >= items.score.numberOfSubLevels) {
         items.bonus.good("flower")
         return
     }
@@ -135,23 +126,18 @@ function displayNextHand() {
 }
 
 function isLeft() {
-    return (currentHands[currentImageId].image.indexOf("gauche") !== -1) ? true : false
+    return (currentHands[items.score.currentSubLevel].image.indexOf("gauche") !== -1) ? true : false
 }
 
-function leftClick() {
-    if(isLeft()) {
-        displayNextHand()
-    }
-}
 
 function isRight() {
-    return (currentHands[currentImageId].image.indexOf("droit") !== -1) ? true : false
+    return (currentHands[items.score.currentSubLevel].image.indexOf("droit") !== -1) ? true : false
 }
 
-function rightClick() {
-    if(isRight()) {
-        displayNextHand()
-    }
+
+function goodAnswerPressed() {
+    items.score.currentSubLevel++;
+    items.score.playWinAnimation();
 }
 
 function leftClickPressed() {
