@@ -12,9 +12,7 @@
 .import QtQuick 2.12 as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel = 0
 var numberOfLevel
-var currentSubLevel = 0
 var currentNote = 0
 var items
 var levels
@@ -22,9 +20,9 @@ var isIntroductoryAudioPlaying = false
 
 function start(items_) {
     items = items_
-    currentLevel = 0
     levels = items.parser.parseFromUrl("qrc:/gcompris/src/activities/play_rhythm/resource/dataset.json").levels
     numberOfLevel = levels.length
+    items.currentLevel = Core.getInitialLevel(numberOfLevel)
     items.introductoryAudioTimer.start()
     initLevel()
 }
@@ -33,23 +31,21 @@ function stop() {
     items.introductoryAudioTimer.stop()
     items.metronomeOscillation.stop()
     items.multipleStaff.stopAudios()
+    items.score.stopWinAnimation()
 }
 
 function initLevel() {
-    items.bar.level = currentLevel + 1
-    currentSubLevel = 0
-    Core.shuffle(levels[currentLevel].melodies)
-    items.multipleStaff.isPulseMarkerDisplayed = levels[currentLevel].pulseMarkerVisible
-    items.isMetronomeVisible = levels[currentLevel].metronomeVisible
+    items.score.currentSubLevel = 0
+    Core.shuffle(levels[items.currentLevel].melodies)
+    items.multipleStaff.isPulseMarkerDisplayed = levels[items.currentLevel].pulseMarkerVisible
+    items.isMetronomeVisible = levels[items.currentLevel].metronomeVisible
     nextSubLevel()
     currentNote = 0
 }
 
 function nextSubLevel() {
-    currentSubLevel++
-    items.score.currentSubLevel = currentSubLevel
-    if(currentSubLevel > items.score.numberOfSubLevels)
-        nextLevel()
+    if(items.score.currentSubLevel >= items.score.numberOfSubLevels)
+        items.bonus.good("note")
     else
         initSubLevel()
 }
@@ -66,37 +62,51 @@ function checkAnswer(pulseMarkerX) {
             items.isWrongRhythm = true
         }
     }
-    if((currentNote >= items.multipleStaff.musicElementModel.count - 1)) {
-        if(!items.isWrongRhythm)
-            items.bonus.good("flower")
-        else
-            items.bonus.bad("flower")
+    if(currentNote > 0 && !items.multipleStaff.isMusicPlaying) {
+        items.isWrongRhythm = true
+        items.buttonsBlocked = true
+        items.answerFeedbackTimer.restart()
+    } else if((currentNote >= items.multipleStaff.musicElementModel.count - 1)) {
+        items.buttonsBlocked = true
+        items.answerFeedbackTimer.restart()
+    }
+}
+
+function answerFeedback() {
+    if(!items.isWrongRhythm) {
+        items.score.currentSubLevel += 1
+        items.score.playWinAnimation()
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav")
+    } else {
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav")
+        items.crashPlayed = true
+        items.answerFeedbackTimer.restart()
     }
 }
 
 function initSubLevel() {
-     items.metronomeOscillation.stop()
-     items.multipleStaff.stopAudios()
-     currentNote = 0
-     var currentSubLevelMelody = levels[currentLevel].melodies[currentSubLevel - 1]
-     items.multipleStaff.loadFromData(currentSubLevelMelody)
-     items.background.isRhythmPlaying = true
-     items.isWrongRhythm = false
+    items.metronomeOscillation.stop()
+    items.multipleStaff.stopAudios()
+    currentNote = 0
+    var currentSubLevelMelody = levels[items.currentLevel].melodies[items.score.currentSubLevel]
+    items.multipleStaff.loadFromData(currentSubLevelMelody)
+    items.background.isRhythmPlaying = true
+    items.isWrongRhythm = false
 
-     if(!isIntroductoryAudioPlaying && !items.iAmReady.visible)
-         items.multipleStaff.play()
+    if(!isIntroductoryAudioPlaying && !items.iAmReady.visible)
+        items.multipleStaff.play()
+
+    items.buttonsBlocked = false
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0
-    }
+    items.score.stopWinAnimation()
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     initLevel()
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1
-    }
+    items.score.stopWinAnimation()
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel()
 }
