@@ -12,7 +12,6 @@
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 
-var currentLevel;
 var numberOfLevel;
 var items;
 var position;
@@ -32,8 +31,7 @@ function start(items_) {
     items = items_;
     dataset = items.levels;
     numberOfLevel = dataset.length;
-    currentLevel = 0;
-    items.score.currentSubLevel = 1;
+    items.currentLevel = Core.getInitialLevel(numberOfLevel);
     initLevel();
 }
 
@@ -41,15 +39,16 @@ function stop() {
 }
 
 function initLevel() {
-    items.bar.level = currentLevel + 1;
+    items.score.stopWinAnimation();
+    items.errorRectangle.resetState();
     questionList = [];
 
-    questionList = dataset[currentLevel].questions;
+    questionList = dataset[items.currentLevel].questions;
+    items.score.currentSubLevel = 0;
     items.score.numberOfSubLevels = questionList.length;
-    items.currentLevel = items.bar.level;
     currentQuestionIndex = -1;
 
-    if(dataset[currentLevel].generateRandomPositions) {
+    if(dataset[items.currentLevel].generateRandomPositions) {
         questionList = Core.shuffle(questionList);
     }
 
@@ -57,34 +56,32 @@ function initLevel() {
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0;
-    }
-    items.score.currentSubLevel = 1;
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1;
-    }
-    items.score.currentSubLevel = 1;
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
     initLevel();
 }
 
 function verifyAnswer() {
+    items.buttonsBlocked = true;
     if(items.selectedPosition === items.checkState) {
-        items.bonus.good("flower");
+        items.score.currentSubLevel += 1;
+        items.score.playWinAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
     }
     else {
-        items.bonus.bad("flower");
+        items.errorRectangle.startAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
     }
 }
 
 function nextSubLevel() {
     currentQuestionIndex++;
     if(currentQuestionIndex >= questionList.length) {
-        nextLevel();
+        items.bonus.good("flower");
         return;
     }
     items.positionModels.clear();
@@ -94,7 +91,7 @@ function nextSubLevel() {
     }
     items.view.currentIndex = -1;
     getRandomPositions();
-    items.score.currentSubLevel = currentQuestionIndex;
+    items.buttonsBlocked = false;
 }
 
 function getRandomPositions() {
