@@ -5,6 +5,7 @@
  * Authors:
  *   Bruno Coudoin <bruno.coudoin@gcompris.net> (GTK+ version)
  *   Johnny Jazeix <jazeix@gmail.com> (Qt Quick port)
+ *   Timothée Giet <animtim@gmail.com> (graphics and improvements)
  *
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
@@ -13,7 +14,6 @@
 .import GCompris 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel = 0
 var items
 var maxLevel
 
@@ -27,7 +27,7 @@ var words
 
 function start(items_) {
     items = items_
-    currentLevel = 0
+    items.score.currentSubLevel = 0
     var locale = items.locale == "system" ? "$LOCALE" : items.locale
 
     items.wordlist.loadFromFile(GCompris.ApplicationInfo.getLocaleFilePath(
@@ -52,6 +52,7 @@ function start(items_) {
         items.wordlist.useDefault = false
     }
     maxLevel = items.wordlist.maxLevel;
+    items.currentLevel = Core.getInitialLevel(maxLevel);
     initLevel();
 }
 
@@ -60,35 +61,71 @@ function stop() {
 }
 
 function initLevel() {
-    items.bar.level = currentLevel + 1;
+    items.score.currentSubLevel = 0
     items.wordDropTimer.stop();
     items.answerButtonsFlow.visible = false;
 
     // initialize level
-    level = items.wordlist.getLevelWordList(currentLevel + 1);
-    items.wordlist.initRandomWord(currentLevel + 1)
+    level = items.wordlist.getLevelWordList(items.currentLevel + 1);
+    items.wordlist.initRandomWord(items.currentLevel + 1)
+    items.score.numberOfSubLevels = Math.min(10, Math.floor(level.words.length))
+    initSubLevel();
+}
+
+function initSubLevel() {
+    items.answerButtonsFlow.visible = false;
     items.textToFind = items.wordlist.getRandomWord()
     Core.shuffle(level.words)
     words = level.words.slice(0, 15)
+    // add 1/2 probablity for yes/no answer
+    var probability = Math.random()
+    if(probability > 0.5) {     // answer should be yes
+        if(words.indexOf(items.textToFind) == -1) {
+            words.pop()
+            words.push(items.textToFind)
+        }
+    } else if(words.indexOf(items.textToFind) > -1) {    // answer should be no
+        var wordIndex = words.indexOf(items.textToFind)  // if word is included, remove it
+        words.splice(wordIndex, 1)
+        for(var i=level.words.length - 1; i == 0; i--) { // try to get a word from the whole list different from textToFind and not yet in words
+            if(level.words[i] != items.textToFind && words.indexOf(level.words[i]) == -1) {
+                var wordToAdd = level.words[i]
+                words.push(wordToAdd)
+                break
+            }
+        }
+    }
+    Core.shuffle(words)
+
     items.currentIndex = -1
 
     items.wordDisplayRepeater.model = words
     items.wordDisplayRepeater.idToHideBecauseOverflow = 0
     items.answerButtonFound.isCorrectAnswer = words.indexOf(items.textToFind) != -1
     items.iAmReady.visible = true
+    items.buttonsBlocked = false
+}
+
+function retrySubLevel() {
+    items.wordlist.appendRandomWord(items.textToFind);
+    initSubLevel();
+}
+
+function nextSubLevel() {
+    if(items.score.currentSubLevel >= items.score.numberOfSubLevels) {
+        items.bonus.good("flower")
+    } else {
+        initSubLevel();
+    }
 }
 
 function nextLevel() {
-    if(maxLevel <= ++currentLevel) {
-        currentLevel = 0
-    }
+    items.currentLevel = Core.getNextLevel(items.currentLevel, maxLevel);
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = maxLevel - 1
-    }
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, maxLevel);
     initLevel();
 }
 
