@@ -10,11 +10,9 @@
  */
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris
+.import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel = 0;
 var maxLevel = 8;
-var currentSubLevel = 0;
 var maxSubLevel = 6;
 var items;
 var baseUrl = "qrc:/gcompris/src/activities/graph-coloring/resource/shapes/";
@@ -64,8 +62,8 @@ var STATUS_CORRECT = 2;
 
 function start(items_) {
     items = items_;
-    currentLevel = 0;
-    currentSubLevel = 0;
+    items.currentLevel = Core.getInitialLevel(maxLevel);
+    items.score.currentSubLevel = 0;
     initLevel();
 }
 
@@ -73,25 +71,19 @@ function stop() {
 }
 
 function initLevel() {
-    if (currentSubLevel == 0) {
-        // init level
-        items.bar.level = currentLevel + 1;
-    }
-
     // init sublevel
-    ackColors = new Array(levels[currentLevel].numberOfPieces);
+    ackColors = new Array(levels[items.currentLevel].numberOfPieces);
     items.score.numberOfSubLevels = maxSubLevel;
-    items.score.currentSubLevel = currentSubLevel + 1;
     var selectedColors = new Array(maxColors);
-    solution = new Array(levels[currentLevel].numberOfPieces);
+    solution = new Array(levels[items.currentLevel].numberOfPieces);
     for (var i = 0; i < maxColors; ++i)
         selectedColors[i] = false;
     // generate solution:
-    for(var i = 0; i < levels[currentLevel].numberOfPieces; ++i) {
+    for(var i = 0; i < levels[items.currentLevel].numberOfPieces; ++i) {
         var j;
         do
-            j = Math.floor(Math.random() * levels[currentLevel].numberOfColors);
-        while (levels[currentLevel].uniqueColors && selectedColors[j]);
+            j = Math.floor(Math.random() * levels[items.currentLevel].numberOfColors);
+        while (levels[items.currentLevel].uniqueColors && selectedColors[j]);
 
         solution[i] = j;
         selectedColors[j] = true;
@@ -101,7 +93,7 @@ function initLevel() {
     items.colorsRepeater.model.clear();
     items.currentRepeater.model = new Array();
     currentIndeces = new Array();
-    for (var i = 0; i < levels[currentLevel].numberOfColors; ++i) {
+    for (var i = 0; i < levels[items.currentLevel].numberOfColors; ++i) {
         currentIndeces[i] = i;
         items.colorsRepeater.model.append({"itemIndex": i});
     }
@@ -109,12 +101,12 @@ function initLevel() {
     // add first guess row:
     items.guessModel.clear();
     appendGuessRow();
+    items.buttonsBlocked = false;
 }
 
-function appendGuessRow()
-{
+function appendGuessRow() {
     var guessRow = new Array();
-    for (var i = 0; i < levels[currentLevel].numberOfPieces; ++i) {
+    for (var i = 0; i < levels[items.currentLevel].numberOfPieces; ++i) {
         var col =
         guessRow.push({
                           index: i,
@@ -131,8 +123,7 @@ function appendGuessRow()
     items.currentRepeater.model = obj.guess;
 }
 
-function ackColor(column, colIndex)
-{
+function ackColor(column, colIndex) {
     ackColors[column] = (ackColors[column] == colIndex) ?  undefined : colIndex;
     for (var i = 0; i < items.guessModel.count; i++) {
         var obj = items.guessModel.get(i).guess.get(column);
@@ -142,40 +133,50 @@ function ackColor(column, colIndex)
     items.currentRepeater.model.get(column).isAcked = (ackColors[column] !== undefined);
 }
 
-function checkGuess()
-{
-    var remainingIndeces = solution.slice();
+function checkGuess() {
     var obj = items.guessModel.get(0);
     var correctCount = 0;
     var misplacedCount = 0;
+
+    // these will be used to check for mismatches later
+    var remainingIndices = [];  // stores indices where mismatches can happen
+    var remainingColors = [];   // stores the solution values at those indices
+
     // check for exact matches first:
-    for (var i = 0; i < levels[currentLevel].numberOfPieces; i++) {
+    for (var i = 0; i < levels[items.currentLevel].numberOfPieces; i++) {
         var guessIndex = obj.guess.get(i).colIndex;
         var newStatus;
         if (solution[i] == guessIndex) {
             // correct
-            remainingIndeces.splice(remainingIndeces.indexOf(guessIndex), 1);
-            if (levels[currentLevel].help)
+            if (levels[items.currentLevel].help)
                 obj.guess.setProperty(i, "status", STATUS_CORRECT);
             correctCount++;
         }
+        else {
+            remainingIndices.push(i);
+            remainingColors.push(solution[i]);
+        }
     }
     obj.result = ({ correct: correctCount });
-    if (remainingIndeces.length == 0) {
-        items.bonus.good("smiley");
+    if (remainingIndices.length == 0) {
+        items.buttonsBlocked = true;
+        items.score.currentSubLevel += 1;
+        items.score.playWinAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
     }
 
-    for (var i = 0; i < levels[currentLevel].numberOfPieces; i++) {
-        if (obj.guess.get(i).status == STATUS_CORRECT)
-            continue;
-        var guessIndex = obj.guess.get(i).colIndex;
+    for (var i = 0; i < remainingIndices.length; i++) {
+        var index = remainingIndices[i];
+        var guessIndex = obj.guess.get(index).colIndex;
         var newStatus = STATUS_UNKNOWN;
-        if (solution.indexOf(guessIndex) != -1 &&
-                remainingIndeces.indexOf(guessIndex) != -1) {
+        if (remainingColors.indexOf(guessIndex) != -1) {
             // misplaced
-            remainingIndeces.splice(remainingIndeces.indexOf(guessIndex), 1);
-            if (levels[currentLevel].help)
-                obj.guess.setProperty(i, "status", STATUS_MISPLACED);
+            if (levels[items.currentLevel].help)
+                obj.guess.setProperty(index, "status", STATUS_MISPLACED);
+
+            // remove guessIndex from remainingColors, so that multiple mismatches are not reported
+            remainingColors.splice(remainingColors.indexOf(guessIndex), 1)
+
             misplacedCount++;
         }
     }
@@ -185,25 +186,24 @@ function checkGuess()
 }
 
 function nextLevel() {
-    if(maxLevel <= ++currentLevel ) {
-        currentLevel = 0;
-    }
-    currentSubLevel = 0;
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getNextLevel(items.currentLevel, maxLevel);
+    items.score.currentSubLevel = 0;
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = maxLevel - 1
-    }
-    currentSubLevel = 0;
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, maxLevel);
+    items.score.currentSubLevel = 0;
     initLevel();
 }
 
 function nextSubLevel() {
-    if( ++currentSubLevel >= maxSubLevel) {
-        currentSubLevel = 0
-        nextLevel()
+    if(items.score.currentSubLevel >= maxSubLevel) {
+        items.bonus.good("smiley");
+    }
+    else {
+        initLevel();
     }
-    initLevel();
 }
