@@ -332,3 +332,10 @@ bool ActivityInfo::hasDataset() const
 {
     return !m_levels.empty();
 }
+
+void ActivityInfo::resetLevels()
+{
+    enableDatasetsBetweenDifficulties(1, 6);
+}
+
+#include "moc_ActivityInfo.cpp"
