@@ -19,6 +19,7 @@ class ActivityInfoTree : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(ActivityInfo *rootMenu READ getRootMenu CONSTANT)
+    Q_PROPERTY(QQmlListProperty<ActivityInfo> menuTreeFull READ getMenuTreeFull CONSTANT)
     Q_PROPERTY(QQmlListProperty<ActivityInfo> menuTree READ menuTree NOTIFY menuTreeChanged)
     Q_PROPERTY(ActivityInfo *currentActivity READ getCurrentActivity WRITE setCurrentActivity NOTIFY currentActivityChanged)
     Q_PROPERTY(QVariantList characters READ allCharacters CONSTANT)
@@ -26,7 +27,7 @@ class ActivityInfoTree : public QObject
      * Specify the activity to start on when running GCompris if --launch is specified in command-line.
      */
     Q_PROPERTY(QString startingActivity MEMBER m_startingActivity NOTIFY startingActivityChanged)
-
+    Q_PROPERTY(int startingLevel MEMBER m_startingLevel NOTIFY startingLevelChanged)
 public:
     static ActivityInfoTree *getInstance()
     {
@@ -36,6 +37,7 @@ public:
         return m_instance;
     }
     QQmlListProperty<ActivityInfo> menuTree();
+    QQmlListProperty<ActivityInfo> getMenuTreeFull();
     ActivityInfo *getRootMenu() const;
     void setRootMenu(ActivityInfo *rootMenu);
     ActivityInfo *menuTree(int) const;
@@ -47,7 +49,11 @@ public:
     void sortByDifficultyThenName(bool emitChanged = true);
     QVariantList allCharacters();
 
-    static void setStartingActivity(const QString &startingActivity) { m_startingActivity = startingActivity; }
+    static void setStartingActivity(const QString &startingActivity, int startingLevel)
+    {
+        m_startingActivity = startingActivity;
+        m_startingLevel = startingLevel;
+    }
 
 protected:
     static ActivityInfoTree *m_instance;
@@ -55,6 +61,7 @@ protected:
 public Q_SLOTS:
     Q_INVOKABLE void minMaxFiltersChanged(quint32 levelMin, quint32 levelMax, bool doSynchronize = true);
     Q_INVOKABLE void filterByTag(const QString &tag, const QString &category = "", bool emitChanged = true);
+    Q_INVOKABLE void resetLevels(const QString &activity);
 
 protected Q_SLOTS:
     Q_INVOKABLE void filterEnabledActivities(bool emitChanged = true);
@@ -70,6 +77,7 @@ Q_SIGNALS:
     void currentActivityChanged();
     void allCharactersChanged();
     void startingActivityChanged();
+    void startingLevelChanged();
 
 private:
     explicit ActivityInfoTree(QObject *parent = nullptr);
@@ -82,10 +90,14 @@ private:
     ActivityInfo *m_currentActivity;
     QVariantList m_keyboardCharacters;
     static QString m_startingActivity;
+    static int m_startingLevel;
 
     static QList<ActivityInfo>::size_type menuTreeCount(QQmlListProperty<ActivityInfo> *property);
     static ActivityInfo *menuTreeAt(QQmlListProperty<ActivityInfo> *property, QList<ActivityInfo>::size_type index);
 
+    static QList<ActivityInfo>::size_type menuTreeFullCount(QQmlListProperty<ActivityInfo> *property);
+    static ActivityInfo *menuTreeFullAt(QQmlListProperty<ActivityInfo> *property, QList<ActivityInfo>::size_type index);
+
     static QStringList getActivityList();
 
 public:
