@@ -20,57 +20,57 @@
 
 #include <QtQml>
 
-#define GC_DEFAULT_FONT QLatin1String("Andika-R.ttf")
-#define GC_DEFAULT_FONT_CAPITALIZATION 0 // Font.MixedCase
-#define GC_DEFAULT_FONT_LETTER_SPACING 0
+namespace {
+    const char *GC_DEFAULT_FONT = "Andika-R.ttf";
+    constexpr int GC_DEFAULT_FONT_CAPITALIZATION = 0; // Font.MixedCase
+    constexpr int GC_DEFAULT_FONT_LETTER_SPACING = 0;
 
-static const char *GENERAL_GROUP_KEY = "General";
-static const char *ADMIN_GROUP_KEY = "Admin";
-static const char *INTERNAL_GROUP_KEY = "Internal";
-static const char *FAVORITE_GROUP_KEY = "Favorite";
-static const char *LEVELS_GROUP_KEY = "Levels";
+    const char *GENERAL_GROUP_KEY = "General";
+    const char *ADMIN_GROUP_KEY = "Admin";
+    const char *INTERNAL_GROUP_KEY = "Internal";
+    const char *FAVORITE_GROUP_KEY = "Favorite";
+    const char *LEVELS_GROUP_KEY = "Levels";
 
-static const char *FULLSCREEN_KEY = "fullscreen";
-static const char *PREVIOUS_HEIGHT_KEY = "previousHeight";
-static const char *PREVIOUS_WIDTH_KEY = "previousWidth";
-static const char *ENABLE_AUDIO_VOICES_KEY = "enableAudioVoices";
-static const char *ENABLE_AUDIO_EFFECTS_KEY = "enableAudioEffects";
-static const char *ENABLE_BACKGROUND_MUSIC_KEY = "enableBackgroundMusic";
-static const char *VIRTUALKEYBOARD_KEY = "virtualKeyboard";
-static const char *LOCALE_KEY = "locale";
-static const char *FONT_KEY = "font";
-static const char *IS_CURRENT_FONT_EMBEDDED = "isCurrentFontEmbedded";
-static const char *ENABLE_AUTOMATIC_DOWNLOADS = "enableAutomaticDownloads";
-static const char *FILTERED_BACKGROUND_MUSIC_KEY = "filteredBackgroundMusic";
-static const char *BACKGROUND_MUSIC_VOLUME_KEY = "backgroundMusicVolume";
-static const char *AUDIO_EFFECTS_VOLUME_KEY = "audioEffectsVolume";
+    const char *FULLSCREEN_KEY = "fullscreen";
+    const char *PREVIOUS_HEIGHT_KEY = "previousHeight";
+    const char *PREVIOUS_WIDTH_KEY = "previousWidth";
+    const char *ENABLE_AUDIO_VOICES_KEY = "enableAudioVoices";
+    const char *ENABLE_AUDIO_EFFECTS_KEY = "enableAudioEffects";
+    const char *ENABLE_BACKGROUND_MUSIC_KEY = "enableBackgroundMusic";
+    const char *VIRTUALKEYBOARD_KEY = "virtualKeyboard";
+    const char *LOCALE_KEY = "locale";
+    const char *FONT_KEY = "font";
+    const char *IS_CURRENT_FONT_EMBEDDED = "isCurrentFontEmbedded";
+    const char *ENABLE_AUTOMATIC_DOWNLOADS = "enableAutomaticDownloads";
+    const char *FILTERED_BACKGROUND_MUSIC_KEY = "filteredBackgroundMusic";
+    const char *BACKGROUND_MUSIC_VOLUME_KEY = "backgroundMusicVolume";
+    const char *AUDIO_EFFECTS_VOLUME_KEY = "audioEffectsVolume";
 
-static const char *DOWNLOAD_SERVER_URL_KEY = "downloadServerUrl";
-static const char *CACHE_PATH_KEY = "cachePath";
-static const char *USERDATA_PATH_KEY = "userDataPath";
-static const char *RENDERER_KEY = "renderer";
+    const char *DOWNLOAD_SERVER_URL_KEY = "downloadServerUrl";
+    const char *CACHE_PATH_KEY = "cachePath";
+    const char *USERDATA_PATH_KEY = "userDataPath";
+    const char *RENDERER_KEY = "renderer";
 
-static const char *EXE_COUNT_KEY = "exeCount";
-static const char *LAST_GC_VERSION_RAN = "lastGCVersionRan";
+    const char *EXE_COUNT_KEY = "exeCount";
+    const char *LAST_GC_VERSION_RAN = "lastGCVersionRan";
 
-static const char *FILTER_LEVEL_MIN = "filterLevelMin";
-static const char *FILTER_LEVEL_MAX = "filterLevelMax";
+    const char *FILTER_LEVEL_MIN = "filterLevelMin";
+    const char *FILTER_LEVEL_MAX = "filterLevelMax";
 
-static const char *BASE_FONT_SIZE_KEY = "baseFontSize";
-static const char *FONT_CAPITALIZATION = "fontCapitalization";
-static const char *FONT_LETTER_SPACING = "fontLetterSpacing";
+    const char *BASE_FONT_SIZE_KEY = "baseFontSize";
+    const char *FONT_CAPITALIZATION = "fontCapitalization";
+    const char *FONT_LETTER_SPACING = "fontLetterSpacing";
 
-static const char *DEFAULT_CURSOR = "defaultCursor";
-static const char *NO_CURSOR = "noCursor";
-static const char *KIOSK_KEY = "kiosk";
-static const char *SECTION_VISIBLE = "sectionVisible";
-static const char *EXIT_CONFIRMATION = "exitConfirmation";
-static const char *WORDSET = "wordset";
-static const char *USE_WORDSET = "useWordset";
+    const char *DEFAULT_CURSOR = "defaultCursor";
+    const char *NO_CURSOR = "noCursor";
+    const char *KIOSK_KEY = "kiosk";
+    const char *SECTION_VISIBLE = "sectionVisible";
+    const char *EXIT_CONFIRMATION = "exitConfirmation";
 
-static const char *PROGRESS_KEY = "progress";
+    const char *PROGRESS_KEY = "progress";
 
-static const char *DEFAULT_DOWNLOAD_SERVER = "https://cdn.kde.org/gcompris";
+    const char *DEFAULT_DOWNLOAD_SERVER = "https://cdn.kde.org/gcompris";
+}
 
 ApplicationSettings *ApplicationSettings::m_instance = nullptr;
 
@@ -95,7 +95,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
                                          ApplicationInfo::getInstance()->isMobile())
                               .toBool();
     m_locale = m_config.value(LOCALE_KEY, GC_DEFAULT_LOCALE).toString();
-    m_font = m_config.value(FONT_KEY, GC_DEFAULT_FONT).toString();
+    m_font = m_config.value(FONT_KEY, QLatin1String(GC_DEFAULT_FONT)).toString();
     if (m_font == QLatin1String("Andika-R.otf"))
         m_font = "Andika-R.ttf";
     m_fontCapitalization = m_config.value(FONT_CAPITALIZATION, GC_DEFAULT_FONT_CAPITALIZATION).toUInt();
@@ -113,13 +113,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
 
     m_sectionVisible = m_config.value(SECTION_VISIBLE, true).toBool();
     m_exitConfirmation = m_config.value(EXIT_CONFIRMATION, ApplicationInfo::getInstance()->isMobile() ? true : false).toBool();
-    m_wordset = m_config.value(WORDSET, "").toString();
 
-    // Automatically override the previous rcc with the new one
-    if (m_wordset == QLatin1String("data2/words/words.rcc"))
-        m_wordset = "data2/words/words-webp.rcc";
-
-    m_useWordset = m_config.value(USE_WORDSET, true).toBool();
     m_isAutomaticDownloadsEnabled = m_config.value(ENABLE_AUTOMATIC_DOWNLOADS,
                                                    !ApplicationInfo::getInstance()->isMobile() && ApplicationInfo::isDownloadAllowed())
                                         .toBool();
@@ -142,7 +136,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
 #if defined(UBUNTUTOUCH)
     m_userDataPath = m_config.value(USERDATA_PATH_KEY, QStandardPaths::writableLocation(QStandardPaths::AppDataLocation)).toString();
 #else
-    m_userDataPath = m_config.value(USERDATA_PATH_KEY, QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/GCompris")).toString();
+    m_userDataPath = m_config.value(USERDATA_PATH_KEY, QString(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/GCompris"))).toString();
 #endif
     m_renderer = m_config.value(RENDERER_KEY, GRAPHICAL_RENDERER).toString();
     m_config.endGroup();
@@ -171,8 +165,6 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     connect(this, &ApplicationSettings::filterLevelMaxChanged, this, &ApplicationSettings::notifyFilterLevelMaxChanged);
     connect(this, &ApplicationSettings::sectionVisibleChanged, this, &ApplicationSettings::notifySectionVisibleChanged);
     connect(this, &ApplicationSettings::exitConfirmationChanged, this, &ApplicationSettings::notifyExitConfirmationChanged);
-    connect(this, &ApplicationSettings::wordsetChanged, this, &ApplicationSettings::notifyWordsetChanged);
-    connect(this, &ApplicationSettings::useWordsetChanged, this, &ApplicationSettings::notifyUseWordsetChanged);
     connect(this, &ApplicationSettings::kioskModeChanged, this, &ApplicationSettings::notifyKioskModeChanged);
     connect(this, &ApplicationSettings::downloadServerUrlChanged, this, &ApplicationSettings::notifyDownloadServerUrlChanged);
     connect(this, &ApplicationSettings::cachePathChanged, this, &ApplicationSettings::notifyCachePathChanged);
@@ -210,8 +202,6 @@ ApplicationSettings::~ApplicationSettings()
     m_config.setValue(KIOSK_KEY, m_isKioskMode);
     m_config.setValue(SECTION_VISIBLE, m_sectionVisible);
     m_config.setValue(EXIT_CONFIRMATION, m_exitConfirmation);
-    m_config.setValue(WORDSET, m_wordset);
-    m_config.setValue(USE_WORDSET, m_useWordset);
     m_config.setValue(DEFAULT_CURSOR, m_defaultCursor);
     m_config.setValue(NO_CURSOR, m_noCursor);
     m_config.setValue(BASE_FONT_SIZE_KEY, m_baseFontSize);
@@ -378,24 +368,6 @@ void ApplicationSettings::notifyExitConfirmationChanged()
     updateValueInConfig(GENERAL_GROUP_KEY, EXIT_CONFIRMATION, m_exitConfirmation);
 }
 
-void ApplicationSettings::notifyWordsetChanged()
-{
-    if (!m_wordset.isEmpty() && DownloadManager::getInstance()->haveLocalResource(m_wordset) && !DownloadManager::getInstance()->isDataRegistered("words-webp")) {
-        // words-webp.rcc is there -> register old file first
-        // then try to update in the background
-        DownloadManager::getInstance()->updateResource(m_wordset);
-    }
-
-    updateValueInConfig(GENERAL_GROUP_KEY, WORDSET, m_wordset);
-    qDebug() << "notifyWordset: " << m_wordset;
-}
-
-void ApplicationSettings::notifyUseWordsetChanged()
-{
-    updateValueInConfig(GENERAL_GROUP_KEY, USE_WORDSET, m_useWordset);
-    qDebug() << "notifyUseWordset: " << m_useWordset;
-}
-
 void ApplicationSettings::notifyDownloadServerUrlChanged()
 {
     updateValueInConfig(ADMIN_GROUP_KEY, DOWNLOAD_SERVER_URL_KEY, m_downloadServerUrl);
@@ -528,7 +500,7 @@ void ApplicationSettings::saveActivityProgress(const QString &activity, int prog
 
 bool ApplicationSettings::useExternalWordset()
 {
-    return !m_wordset.isEmpty() && DownloadManager::getInstance()->isDataRegistered("words-webp");
+    return DownloadManager::getInstance()->isDataRegistered("words-webp");
 }
 
 QObject *ApplicationSettings::applicationSettingsProvider(QQmlEngine *engine,
@@ -540,3 +512,5 @@ QObject *ApplicationSettings::applicationSettingsProvider(QQmlEngine *engine,
     ApplicationSettings *appSettings = getInstance();
     return appSettings;
 }
+
+#include "moc_ApplicationSettings.cpp"
