@@ -53,7 +53,7 @@ class Dataset : public QObject
 
 public:
     /// @cond INTERNAL_DOCS
-    explicit Dataset(QObject *parent = 0);
+    explicit Dataset(QObject *parent = nullptr);
 
     QString objective() const;
     void setObjective(const QString &);
@@ -64,7 +64,7 @@ public:
     bool enabled() const;
     void setEnabled(const bool &);
     /// @endcond
-signals:
+Q_SIGNALS:
     void objectiveChanged();
     void difficultyChanged();
     void dataChanged();
