@@ -21,9 +21,10 @@
 #include <QDirIterator>
 #include <QCoreApplication>
 
-const QString DownloadManager::contentsFilename = QStringLiteral("Contents");
+const QString DownloadManager::contentsFilename = QLatin1String("Contents");
 DownloadManager *DownloadManager::_instance = nullptr;
 
+const QString DownloadManager::localFolderForData = QLatin1String("data3/");
 /* Public interface: */
 
 DownloadManager::DownloadManager() :
@@ -98,8 +99,19 @@ void DownloadManager::abortDownloads()
                 disconnect(job->reply, SIGNAL(error(QNetworkReply::NetworkError)),
                            this, SLOT(handleError(QNetworkReply::NetworkError)));
                 if (job->reply->isRunning()) {
-                    qDebug() << "Aborting download job:" << job->url;
+                    qDebug() << "Aborting download job:" << job->url << job->resourceType;
                     job->reply->abort();
+
+                    // remove new Contents file before removing the new rcc
+                    QFileInfo fi(job->file.fileName());
+                    QDir dir = fi.dir(); // Get the directory of the file
+                    // Get the filepath of new Contents file
+                    QString newContentsFilePath = tempFilenameForFilename(dir.filePath(contentsFilename));
+                    // remove new Contents file if it exists
+                    if (QFile::exists(newContentsFilePath) && !QFile::remove(newContentsFilePath))
+                        qWarning() << "Error while removing new Contents file" << newContentsFilePath;
+
+                    // close and remove new rcc file
                     job->file.close();
                     job->file.remove();
                 }
@@ -113,15 +125,39 @@ void DownloadManager::abortDownloads()
     }
 }
 
+void DownloadManager::initializeAssets()
+{
+    const QStringList files = {
+        localFolderForData + QLatin1String("Contents"),
+        localFolderForData + QLatin1String("voices-" COMPRESSED_AUDIO "/Contents"),
+        localFolderForData + QLatin1String("backgroundMusic/Contents"),
+        localFolderForData + QLatin1String("words/Contents")
+    };
+    for (const QString &contentsFolder: files) {
+        QFileInfo fi(getAbsoluteResourcePath(contentsFolder));
+        if (fi.exists()) {
+            DownloadJob job(GCompris::ResourceType::NONE);
+            job.file.setFileName(fi.filePath());
+            parseContents(&job);
+        }
+        else {
+            qDebug() << fi.filePath() << "does not exist, cannot parse Contents for " << contentsFolder;
+        }
+    }
+
+    connect(this, &DownloadManager::allDownloadsFinished, this, &DownloadManager::finishAllDownloads);
+}
+
 QString DownloadManager::getVoicesResourceForLocale(const QString &locale) const
 {
-    return QString("data2/voices-" COMPRESSED_AUDIO "/voices-%1.rcc")
-        .arg(ApplicationInfo::getInstance()->getVoicesLocale(locale));
+    const QString localeName = ApplicationInfo::getInstance()->getVoicesLocale(locale);
+    qDebug() << "Get voices for " << locale << ", " << localeName;
+    return getResourcePath(GCompris::ResourceType::VOICES, { { "locale", localeName } });
 }
 
 QString DownloadManager::getBackgroundMusicResources() const
 {
-    return QString("data2/backgroundMusic/backgroundMusic-" COMPRESSED_AUDIO ".rcc");
+    return getResourcePath(GCompris::ResourceType::BACKGROUND_MUSIC, {});
 }
 
 inline QString DownloadManager::getAbsoluteResourcePath(const QString &path) const
@@ -152,36 +188,89 @@ bool DownloadManager::haveLocalResource(const QString &path) const
     return (!getAbsoluteResourcePath(path).isEmpty());
 }
 
-bool DownloadManager::updateResource(const QString &path)
+QString DownloadManager::getLocalSubFolderForData(const GCompris::ResourceType &rt) const
+{
+    switch (rt) {
+    case GCompris::ResourceType::WORDSET:
+        return localFolderForData + QLatin1String("words/");
+        break;
+    case GCompris::ResourceType::BACKGROUND_MUSIC:
+        return localFolderForData + QLatin1String("backgroundMusic/");
+        break;
+    case GCompris::ResourceType::VOICES:
+        return localFolderForData + QLatin1String("voices-" COMPRESSED_AUDIO "/");
+        break;
+    case GCompris::ResourceType::FULL:
+        return localFolderForData;
+        break;
+    default:
+        return QString();
+    }
+    return QString();
+}
+
+QString DownloadManager::getResourcePath(/*const GCompris::ResourceType &rt*/ int rt, const QVariantMap &data) const
+{
+    // qDebug() << "getResourcePath" << GCompris::ResourceType(rt) << resourceTypeToLocalFileName << data["locale"].toString();
+    GCompris::ResourceType resource = GCompris::ResourceType(rt);
+    switch (resource) {
+    case GCompris::ResourceType::WORDSET:
+        if (resourceTypeToLocalFileName.contains("words")) {
+            return getLocalSubFolderForData(resource) + resourceTypeToLocalFileName["words"];
+        }
+        break;
+    case GCompris::ResourceType::BACKGROUND_MUSIC:
+        if (resourceTypeToLocalFileName.contains("backgroundMusic-" COMPRESSED_AUDIO)) {
+            return getLocalSubFolderForData(resource) + resourceTypeToLocalFileName["backgroundMusic-" COMPRESSED_AUDIO];
+        }
+        break;
+    case GCompris::ResourceType::VOICES:
+        if (resourceTypeToLocalFileName.contains(data["locale"].toString())) {
+            return getLocalSubFolderForData(resource) + resourceTypeToLocalFileName[data["locale"].toString()];
+        }
+        break;
+    case GCompris::ResourceType::FULL:
+        if (resourceTypeToLocalFileName.contains("full-" COMPRESSED_AUDIO)) {
+            return getLocalSubFolderForData(resource) + resourceTypeToLocalFileName["full-" COMPRESSED_AUDIO];
+        }
+        break;
+    default:
+        return QString();
+    }
+    return QString();
+}
+
+bool DownloadManager::updateResource(/*const GCompris::ResourceType &*/ int rt, const QVariantMap &extra)
 {
     if (checkDownloadRestriction())
-        return downloadResource(path); // check for updates and register
+        return downloadResource(rt, extra); // check for updates and register
 
-    QString absPath = getAbsoluteResourcePath(path);
+    QString resourcePath = getResourcePath(rt, extra);
+    QString absPath = getAbsoluteResourcePath(resourcePath);
     // automatic download prohibited -> register if available
-    if (!absPath.isEmpty())
+    if (!resourcePath.isEmpty())
         return registerResourceAbsolute(absPath);
 
     qDebug() << "No such local resource and download prohibited: "
-             << path;
+             << GCompris::ResourceType(rt) << extra;
     return false;
 }
 
-bool DownloadManager::downloadResource(const QString &path)
+bool DownloadManager::downloadResource(int rt, const QVariantMap &extra)
 {
     DownloadJob *job = nullptr;
+    GCompris::ResourceType resourceType = GCompris::ResourceType(rt);
     {
         QMutexLocker locker(&jobsMutex);
-        QUrl url(serverUrl.toString() + '/' + path);
-        if (getJobByUrl_locked(url) != nullptr) {
-            qDebug() << "Download of" << url << "is already running, skipping second attempt.";
+        if (getJobByType_locked(resourceType, extra) != nullptr) {
+            qDebug() << "Download of" << resourceType << "is already running, skipping second attempt.";
             return false;
         }
-        job = new DownloadJob(url);
+        job = new DownloadJob(resourceType, extra);
         activeJobs.append(job);
     }
 
-    qDebug() << "Downloading resource file" << path;
+    qDebug() << "downloadResource" << resourceType << extra;
     if (!download(job)) {
         QMutexLocker locker(&jobsMutex);
         activeJobs.removeOne(job);
@@ -209,10 +298,28 @@ bool DownloadManager::download(DownloadJob *job)
     QNetworkRequest request;
 
     // First download Contents file for verification if not yet done:
-    if (!job->contents.contains(job->url.fileName())) {
-        int len = job->url.fileName().length();
-        QUrl contentsUrl = QUrl(job->url.toString().remove(job->url.toString().length() - len, len)
-                                + contentsFilename);
+    if (!job->contents.contains(job->url.fileName()) /*|| job->url.fileName().contains("Contents")*/) {
+        QUrl contentsUrl;
+        if (!job->url.isEmpty()) {
+            int len = job->url.fileName().length();
+            contentsUrl = QUrl(job->url.toString().remove(job->url.toString().length() - len, len)
+                               + contentsFilename);
+        }
+        else {
+            switch (job->resourceType) {
+            case GCompris::ResourceType::BACKGROUND_MUSIC:
+                contentsUrl = QUrl(serverUrl.toString() + '/' + localFolderForData + "backgroundMusic/" + contentsFilename);
+                break;
+            case GCompris::ResourceType::VOICES:
+                contentsUrl = QUrl(serverUrl.toString() + '/' + localFolderForData + "voices-" COMPRESSED_AUDIO + '/' + contentsFilename);
+                break;
+            case GCompris::ResourceType::WORDSET:
+                contentsUrl = QUrl(serverUrl.toString() + '/' + localFolderForData + "words/" + contentsFilename);
+                break;
+            default:
+                break;
+            }
+        }
         if (!job->knownContentsUrls.contains(contentsUrl)) {
             // Note: need to track already tried Contents files or we can end
             // up in an infinite loop if corresponding Contents file does not
@@ -228,7 +335,7 @@ bool DownloadManager::download(DownloadJob *job)
     // make sure target path exists:
     QDir dir;
     if (!dir.exists(fi.path()) && !dir.mkpath(fi.path())) {
-        qDebug() << "Could not create resource path " << fi.path();
+        // qDebug() << "Could not create resource path " << fi.path();
         Q_EMIT error(QNetworkReply::ProtocolUnknownError, QObject::tr("Could not create resource path"));
         return false;
     }
@@ -242,7 +349,7 @@ bool DownloadManager::download(DownloadJob *job)
 
     // start download:
     request.setUrl(job->url);
-    // qDebug() << "Now downloading" << job->url << "to" << fi.filePath() << "...";
+    qDebug() << "Now downloading" << job->url << "to" << fi.filePath() << "...";
     QNetworkReply *reply = accessManager.get(request);
     job->reply = reply;
     connect(reply, SIGNAL(finished()), this, SLOT(finishDownload()));
@@ -258,10 +365,10 @@ bool DownloadManager::download(DownloadJob *job)
     return true;
 }
 
-inline DownloadManager::DownloadJob *DownloadManager::getJobByUrl_locked(const QUrl &url) const
+inline DownloadManager::DownloadJob *DownloadManager::getJobByType_locked(GCompris::ResourceType rt, const QVariantMap &data) const
 {
     for (auto activeJob: activeJobs)
-        if (activeJob->url == url || activeJob->queue.indexOf(url) != -1)
+        if (activeJob->resourceType == rt && activeJob->extraInfos == data) // || activeJob->queue.indexOf(url) != -1)
             return activeJob;
     return nullptr;
 }
@@ -373,6 +480,26 @@ bool DownloadManager::parseContents(DownloadJob *job)
             return false;
         }
         job->contents[parts[1]] = parts[0];
+        if (parts[1].startsWith(QLatin1String("voices"))) {
+            QString locale = parts[1];
+            locale.remove(0, locale.indexOf('-') + 1); // Remove "voices-" prefix
+            locale = locale.left(locale.indexOf('-')); // Remove the date and ".rcc" suffix
+            // Retrieve locale from filename
+            resourceTypeToLocalFileName[locale] = parts[1];
+            qDebug() << "Contents: " << locale << " -> " << parts[1];
+        }
+        else if (parts[1].startsWith(QLatin1String("words"))) {
+            QString type = parts[1];
+            type = type.left(type.indexOf('-'));
+            resourceTypeToLocalFileName[type] = parts[1];
+            qDebug() << "Contents: " << type << " -> " << parts[1];
+        }
+        else {
+            QString type = parts[1];
+            type = type.section('-', 0, 1); // keep backgroundMusic-$CA or full-$CA
+            resourceTypeToLocalFileName[type] = parts[1];
+            qDebug() << "Contents: " << type << " -> " << parts[1];
+        }
         // qDebug() << "Contents: " << parts[1] << " -> " << parts[0];
     }
     job->file.close();
@@ -440,15 +567,16 @@ bool DownloadManager::registerResourceAbsolute(const QString &filename)
     locker.unlock(); /* note: we unlock before emitting to prevent
                       * potential deadlocks */
 
-    Q_EMIT resourceRegistered(getRelativeResourcePath(filename));
+    const QString relativeFilename = getRelativeResourcePath(filename);
+    Q_EMIT resourceRegistered(relativeFilename);
 
     QString v = getVoicesResourceForLocale(
         ApplicationSettings::getInstance()->locale());
     QString musicPath = getBackgroundMusicResources();
 
-    if (v == getRelativeResourcePath(filename))
+    if (v == relativeFilename)
         Q_EMIT voicesRegistered();
-    else if (musicPath == getRelativeResourcePath(filename))
+    else if (musicPath == relativeFilename)
         Q_EMIT backgroundMusicRegistered();
     return true;
 }
@@ -458,7 +586,14 @@ bool DownloadManager::registerResourceAbsolute(const QString &filename)
  */
 bool DownloadManager::registerResource(const QString &filename)
 {
-    return registerResourceAbsolute(getAbsoluteResourcePath(filename));
+    QString absPath = getAbsoluteResourcePath(filename);
+    if (!absPath.isEmpty()) {
+        return registerResourceAbsolute(getAbsoluteResourcePath(filename));
+    }
+    else {
+        qDebug() << "Error while registering" << filename;
+        return false;
+    }
 }
 
 bool DownloadManager::isDataRegistered(const QString &data) const
@@ -467,9 +602,9 @@ bool DownloadManager::isDataRegistered(const QString &data) const
     return !QDir(res).entryList().empty();
 }
 
-bool DownloadManager::areVoicesRegistered() const
+bool DownloadManager::areVoicesRegistered(const QString &locale) const
 {
-    QString resource = QString("voices-" COMPRESSED_AUDIO "/%1").arg(ApplicationInfo::getInstance()->getVoicesLocale(ApplicationSettings::getInstance()->locale()));
+    QString resource = QString("voices-" COMPRESSED_AUDIO "/%1").arg(ApplicationInfo::getInstance()->getVoicesLocale(locale));
     return isDataRegistered(resource);
 }
 
@@ -498,11 +633,38 @@ void DownloadManager::downloadInProgress(qint64 bytesReceived, qint64 bytesTotal
     Q_EMIT downloadProgress(allJobsBytesReceived, allJobsBytesTotal);
 }
 
+void DownloadManager::finishAllDownloads(int code)
+{
+    QList<QString> registeredFiles = resourceTypeToLocalFileName.values();
+    // Remove all previous rcc for this kind of download
+    for (auto *job: activeJobs) {
+        QString subfolder = getLocalSubFolderForData(job->resourceType);
+        if (subfolder.isEmpty()) {
+            continue;
+        }
+        QDirIterator it(getSystemDownloadPath() + '/' + subfolder);
+        while (it.hasNext()) {
+            QString filename = it.next();
+            QFileInfo fi = it.fileInfo();
+            if (fi.isFile() && (filename.endsWith(QLatin1String(".rcc")))) {
+                if (!registeredFiles.contains(fi.fileName())) {
+                    if (!QFile::remove(filename)) {
+                        qDebug() << "Unable to remove" << filename;
+                    }
+                }
+            }
+        }
+        delete job;
+    }
+    activeJobs.clear();
+}
+
 void DownloadManager::finishDownload()
 {
     QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
     DownloadFinishedCode code = Success;
     DownloadJob *job = getJobByReply(reply);
+    QString targetFilename = getFilenameForUrl(job->url);
     bool allFinished = false;
     if (job->file.isOpen()) {
         job->file.flush(); // note: important, or checksums might be wrong!
@@ -512,18 +674,33 @@ void DownloadManager::finishDownload()
     if (reply->error() != 0 && job->file.exists()) {
         job->file.remove();
     }
-    else {
-        // active temp file
-        QString tFilename = filenameForTempFilename(job->file.fileName());
-        if (QFile::exists(tFilename)) {
-            QFile::remove(tFilename);
+    else if (job->url.fileName() != contentsFilename) {
+        // remove old rcc file and rename the new file
+        // remove old Contents file, rename the new Contents file
+
+        // get corresponding content filename
+        QFileInfo fi(targetFilename);
+        QDir dir = fi.dir(); // Get the directory of the file
+        QString contentsFilePath = dir.filePath(contentsFilename); // Get the filepath of Contents file
+        QString newContentsFilePath = tempFilenameForFilename(contentsFilePath);
+
+        if (QFile::exists(targetFilename)) {
+            QFile::remove(targetFilename);
         }
-        if (!job->file.rename(tFilename)) {
-            qWarning() << "Could not rename temporary file to" << tFilename;
+        if (!job->file.rename(targetFilename)) {
+            qWarning() << "Could not rename temporary file to" << targetFilename;
+            if (!QFile::remove(newContentsFilePath))
+                qWarning() << "Could not remove new Contents file" << newContentsFilePath;
+        }
+        else {
+            // new rcc placed at the required path, now place new contents file
+            if (QFile::exists(contentsFilePath) && !QFile::remove(contentsFilePath))
+                qWarning() << "Could not remove old Contents file" << contentsFilePath;
+            else if (!QFile::rename(newContentsFilePath, contentsFilePath))
+                qWarning() << "Could not rename new Contents file to " << contentsFilePath;
         }
     }
 
-    QString targetFilename = getFilenameForUrl(job->url);
     if (job->url.fileName() == contentsFilename) {
         // Contents
         if (reply->error() != 0) {
@@ -582,6 +759,28 @@ void DownloadManager::finishDownload()
     // try next:
     while (!job->queue.isEmpty()) {
         job->url = job->queue.takeFirst();
+        if (job->url.isEmpty() && job->resourceType != GCompris::ResourceType::NONE) {
+            QString nextDownload = getResourcePath(job->resourceType, job->extraInfos);
+            if (!nextDownload.isEmpty()) {
+                job->url = QUrl(serverUrl.toString() + '/' + nextDownload);
+            }
+            else {
+                if (job->resourceType == GCompris::ResourceType::VOICES) {
+                    const QString localeName = job->extraInfos["locale"].toString();
+                    const QLocale locale(localeName);
+                    Q_EMIT error(QNetworkReply::UnknownContentError,
+                                 QObject::tr("No voices found for %1.")
+                                     .arg(locale.nativeLanguageName()));
+                }
+                else {
+                    Q_EMIT error(QNetworkReply::UnknownContentError,
+                                 QObject::tr("No data found for %1.")
+                                     .arg(GCompris::ResourceType(job->resourceType)));
+                }
+                code = Error;
+                continue;
+            }
+        }
         QString relPath = getRelativeResourcePath(getFilenameForUrl(job->url));
         // check in each resource-path for an up2date rcc file:
         for (const QString &base: getSystemResourcePaths()) {
@@ -597,9 +796,24 @@ void DownloadManager::finishDownload()
                 break;
             }
         }
-        if (code != NoChange) // nothing is up2date locally -> download it
+        if (code != NoChange) {
+            // nothing is up2date locally -> download it
             if (download(job))
                 goto outNext;
+        }
+        else {
+            // data has not changed, remove corresponding Contents file
+            // it is usually removed when rcc is downloaded
+            // in this case, as data has not changed, rcc won't be downloaded
+            QFileInfo fi(job->file.fileName());
+            QDir dir = fi.dir(); // Get the directory of the file
+            // Get the filepath of new Contents file
+            QString newContentsFilePath = tempFilenameForFilename(dir.filePath(contentsFilename));
+
+            if (!QFile::remove(newContentsFilePath)) {
+                qWarning() << "Could not remove new Contents file" << newContentsFilePath;
+            }
+        }
     }
 
     // none left, DownloadJob finished
@@ -619,9 +833,7 @@ void DownloadManager::finishDownload()
                       [&allCode](const DownloadJob *job) {
                           if (job->downloadResult == Error)
                               allCode = Error;
-                          delete job;
                       });
-        activeJobs.clear();
         Q_EMIT allDownloadsFinished(allCode);
     }
     return;
@@ -633,7 +845,7 @@ outError:
         QUrl nUrl;
         while (!job->queue.isEmpty()) {
             nUrl = job->queue.takeFirst();
-            QString relPath = getRelativeResourcePath(getFilenameForUrl(nUrl));
+            QString relPath = getResourcePath(job->resourceType, job->extraInfos);
             for (const QString &base: getSystemResourcePaths()) {
                 QString filename = base + '/' + relPath;
                 if (QFile::exists(filename))
@@ -641,6 +853,17 @@ outError:
             }
         }
     }
+    else {
+        // restore old Contents file
+        QFileInfo fi(job->file.fileName());
+        QDir dir = fi.dir(); // Get the directory of the file
+        // Get the filepath of new Contents file
+        QString newContentsFilePath = tempFilenameForFilename(dir.filePath(contentsFilename));
+
+        if (!QFile::remove(newContentsFilePath)) {
+            qWarning() << "Could not remove new Contents file" << newContentsFilePath;
+        }
+    }
 
     if (job->file.isOpen())
         job->file.close();
@@ -735,3 +958,5 @@ QStringList DownloadManager::getLocalResources()
     return result;
 }
 #endif
+
+#include "moc_DownloadManager.cpp"
